==> phpgroupware-jp-0.9.16.003-pre1.tar.bz2: phpgroupware/eldaptir/index.php <==
<?php
  /**************************************************************************\
  * phpGroupWare - eLDAPtir - LDAP Administration                            *
  * http://www.phpgroupware.org                                              *
  * Written by Miles Lott <milosch@phpgroupware.org>                         *
  * --------------------------------------------                             *
  *  This program is free software; you can redistribute it and/or modify it *
  *  under the terms of the GNU General Public License as published by the   *
  *  Free Software Foundation; either version 2 of the License, or (at your  *
  *  option) any later version.                                              *
  \**************************************************************************/

	/* $Id: index.php,v 1.1.1.2.8.1 2004/09/26 11:15:52 kazuyan Exp $ */

	$server_id = $_GET['server_id'];

	$GLOBALS['phpgw_info']['flags']['currentapp'] = 'eldaptir';
	include('../header.inc.php');

	$GLOBALS['phpgw']->common->check_code($cd);

	echo '<br>'.lang('eldaptir').'<br><br>';

	$servers = servers();
	if ($servers)
	{
		if (!$server_id)
		{
			while(list($key,$test)=each($servers))
			{
				if ($test['default'])
				{
					$server_id = $test['id'];
				}
			}
			if (!$server_id)
			{
				echo'No default set, using phpgw configured server';
			}
		}
		echo '<form method="post" action="'.$GLOBALS['phpgw']->link('/eldaptir/index.php').'">';
		echo server_option($servers,$server_id);
		echo '</form>';
	}

	$ldapobj = CreateObject('eldaptir.ldap',$servers[$server_id]);
	$codecv = CreateObject('phpgwapi.codecv');
	$info = $ldapobj->search();

	echo lang('Organizational Units')."<br>";
	for ($i=0;$i<$ldapobj->total_entries;$i++)
	{
		$ou = $ldapobj->get_ou($info[$i]['dn']);
		if (!ereg('^ou=(.*)', $ou))
			continue;
		$parseou = explode(',', $ou);
		reset($parseou);
		while(list($key,$val) = each($parseou))
		{
			if (ereg('^(.*)=(.*)', $val, $reg))
				$parseou[$key] = $reg[1] . '='. urlencode($reg[2]);
		}
		$ou = implode($parseou, ',');
		//echo $info[$i]['dn'];
		echo '&nbsp;<a href="' . $GLOBALS['phpgw']->link('/eldaptir/viewou.php',$ou.'&server_id='.$server_id) . '">'
			. $codecv->utf8toeuc($info[$i]['ou'][0])."</a><br>\n";
	}
	echo "<br>",lang('Browse')."<br>";
	echo '&nbsp;<a href="' . $GLOBALS['phpgw']->link('/eldaptir/browser.php','server_id='.$server_id). '">' . lang('LDAP Browser') . '</a>';

	$GLOBALS['phpgw']->common->phpgw_footer();
?>

==> phpgroupware-jp-0.9.16.012-pre1.tar.bz2: phpgroupware/eldaptir/index.php <==
<?php
  /**************************************************************************\
  * phpGroupWare - eLDAPtir - LDAP Administration                            *
  * http://www.phpgroupware.org                                              *
  * Written by Miles Lott <milosch@phpgroupware.org>                         *
  * --------------------------------------------                             *
  *  This program is free software; you can redistribute it and/or modify it *
  *  under the terms of the GNU General Public License as published by the   *
  *  Free Software Foundation; either version 2 of the License, or (at your  *
  *  option) any later version.                                              *
  \**************************************************************************/

	/* $Id: index.php,v 1.1.1.2.26.1 2007/09/14 02:11:31 kazuyan Exp $ */

	$server_id = $_GET['server_id'];

	$GLOBALS['phpgw_info']['flags']['currentapp'] = 'eldaptir';
	include('../header.inc.php');

	$GLOBALS['phpgw']->common->check_code($cd);

	echo '<br />'.lang('eldaptir').'<br /><br />';

	$servers = servers();
	if ($servers)
	{
		if (!$server_id)
		{
			while(list($key,$test)=each($servers))
			{
				if ($test['default'])
				{
					$server_id = $test['id'];
				}
			}
			if (!$server_id)
			{
				echo'No default set, using phpgw configured server';
			}
		}
		echo '<form method="post" action="'.$GLOBALS['phpgw']->link('/eldaptir/index.php').'">';
		echo server_option($servers,$server_id);
		echo '</form>';
	}

	$ldapobj = CreateObject('eldaptir.ldap',$servers[$server_id]);
	$codecv = CreateObject('phpgwapi.codecv');
	$info = $ldapobj->search();

	echo lang('Organizational Units')."<br />";
	for ($i=0;$i<$ldapobj->total_entries;$i++)
	{
		$ou = $ldapobj->get_ou($info[$i]['dn']);
		if (!ereg('^ou=(.*)', $ou))
			continue;
		$parseou = explode(',', $ou);
		reset($parseou);
		while(list($key,$val) = each($parseou))
		{
			if (ereg('^(.*)=(.*)', $val, $reg))
				$parseou[$key] = $reg[1] . '='. urlencode($reg[2]);
		}
		$ou = implode($parseou, ',');
		//echo $info[$i]['dn'];
		echo '&nbsp;<a href="' . $GLOBALS['phpgw']->link('/eldaptir/viewou.php',$ou.'&server_id='.$server_id) . '">'
			. $codecv->utf8toeuc($info[$i]['ou'][0])."</a><br />\n";
	}
	echo "<br />",lang('Browse')."<br />";
	echo '&nbsp;<a href="' . $GLOBALS['phpgw']->link('/eldaptir/browser.php','server_id='.$server_id). '">' . lang('LDAP Browser') . '</a>';

	$GLOBALS['phpgw']->common->phpgw_footer();
?>
